@@ -578,8 +578,7 @@ const Application = new Lang.Class({
               state: GLib.Variant.new('b', false),
               accel: 'F5' },
             { name: 'print-current', accel: '<Primary>p',
-              callback: this._onActionPrintCurrent,
-              window_mode: WindowMode.WindowMode.PREVIEW },
+              callback: this._onActionPrintCurrent },
             { name: 'search',
               callback: this._onActionToggle,
               state: GLib.Variant.new('b', false),
