@@ -371,6 +371,13 @@ const DocCommon = new Lang.Class({
         log('Error: DocCommon implementations must override canTrash');
     },
 
+    canPrint: function(docModel) {
+        if (!docModel)
+            return false;
+
+        return EvView.PrintOperation.exists_for_document(docModel.get_document());
+    },
+
     trash: function() {
         if (!this.canTrash())
             return;
@@ -610,6 +617,9 @@ const DocCommon = new Lang.Class({
                     return;
                 }
 
+                if (!this.canPrint(docModel))
+                    return;
+
                 let printOp = EvView.PrintOperation.new(docModel.get_document());
 
                 printOp.connect('begin-print', Lang.bind(this,
