@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013, 2014 Red Hat, Inc.
+ * Copyright (c) 2013, 2014, 2015 Red Hat, Inc.
  *
  * Gnome Documents is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -51,6 +51,10 @@ const EditView = new Lang.Class({
         this.widget.get_style_context().add_class('documents-scrolledwin');
 
         let context = WebKit.WebContext.get_default();
+
+        let cacheDir = GLib.build_filenamev([GLib.get_user_cache_dir(), 'gnome-documents', 'webkit']);
+        context.set_disk_cache_directory(cacheDir);
+
         let cookie_manager = context.get_cookie_manager();
         let jarfile = GLib.build_filenamev([GLib.get_user_cache_dir(), 'gnome-documents', 'cookies.sqlite']);
         cookie_manager.set_persistent_storage(jarfile, WebKit.CookiePersistentStorage.SQLITE);
@@ -82,6 +86,9 @@ const EditView = new Lang.Class({
                 Application.modeController.goBack();
             }));
 
+        this._printAction = Application.application.lookup_action('print-current');
+        this._printAction.set_enabled(false);
+
         Application.documentManager.connect('load-started',
                                             Lang.bind(this, this._onLoadStarted));
         Application.documentManager.connect('load-finished',
@@ -92,6 +99,7 @@ const EditView = new Lang.Class({
     _onLoadStarted: function() {
         this._editAction.enabled = false;
         this._viewAction.enabled = false;
+        this._printAction.set_enabled(false);
     },
 
     _onLoadFinished: function(manager, doc, docModel) {
@@ -99,6 +107,8 @@ const EditView = new Lang.Class({
             if (doc.canEdit())
                 this._editAction.enabled = true;
             this._viewAction.enabled = true;
+            if (doc.canPrint(docModel))
+                this._printAction.set_enabled(true);
         }
     },
 
