@@ -92,66 +92,84 @@ const PreviewView = new Lang.Class({
 
         this._bookmarkPage = Application.application.lookup_action('bookmark-page');
         this._bookmarkPage.enabled = false;
-        this._bookmarkPage.connect('change-state',
+        let bookmarkPageId = this._bookmarkPage.connect('change-state',
             Lang.bind(this, this._onActionStateChanged));
         this._onActionStateChanged(this._bookmarkPage, this._bookmarkPage.state);
 
         this._zoomIn = Application.application.lookup_action('zoom-in');
-        this._zoomIn.connect('activate', Lang.bind(this,
+        let zoomInId = this._zoomIn.connect('activate', Lang.bind(this,
             function() {
                 this._model.set_sizing_mode(EvView.SizingMode.FREE);
                 this.view.zoom_in();
             }));
 
         this._zoomOut = Application.application.lookup_action('zoom-out');
-        this._zoomOut.connect('activate', Lang.bind(this,
+        let zoomOutId = this._zoomOut.connect('activate', Lang.bind(this,
             function() {
                 this._model.set_sizing_mode(EvView.SizingMode.FREE);
                 this.view.zoom_out();
             }));
 
-        this._findPrev = Application.application.lookup_action('find-prev');
-        this._findPrev.connect('activate', Lang.bind(this,
+        let findPrev = Application.application.lookup_action('find-prev');
+        let findPrevId = findPrev.connect('activate', Lang.bind(this,
             function() {
                 this.view.find_previous();
             }));
-        this._findNext = Application.application.lookup_action('find-next');
-        this._findNext.connect('activate', Lang.bind(this,
+        let findNext = Application.application.lookup_action('find-next');
+        let findNextId = findNext.connect('activate', Lang.bind(this,
             function() {
                 this.view.find_next();
             }));
         this._copy = Application.application.lookup_action('copy');
-        this._copy.connect('activate', Lang.bind(this,
+        let copyId = this._copy.connect('activate', Lang.bind(this,
             function() {
                 this.view.copy();
             }));
 
         let rotLeft = Application.application.lookup_action('rotate-left');
-        rotLeft.connect('activate', Lang.bind(this,
+        let rotLeftId = rotLeft.connect('activate', Lang.bind(this,
             function() {
                 this._changeRotation(-90);
             }));
         let rotRight = Application.application.lookup_action('rotate-right');
-        rotRight.connect('activate', Lang.bind(this,
+        let rotRightId = rotRight.connect('activate', Lang.bind(this,
             function() {
                 this._changeRotation(90);
             }));
-        let showPlaces = Application.application.lookup_action('places');
-        showPlaces.connect('activate', Lang.bind(this, this._showPlaces));
+        this._places = Application.application.lookup_action('places');
+        let placesId = this._places.connect('activate', Lang.bind(this, this._showPlaces));
+
+        let nightModeId = Application.application.connect('action-state-changed::night-mode',
+            Lang.bind(this, this._updateNightMode));
 
         this._togglePresentation = Application.application.lookup_action('present-current');
-        Application.application.connect('action-state-changed::present-current',
+        let presentCurrentId = Application.application.connect('action-state-changed::present-current',
             Lang.bind(this, this._onPresentStateChanged));
 
         Application.documentManager.connect('load-started',
                                             Lang.bind(this, this._onLoadStarted));
         Application.documentManager.connect('load-error',
                                             Lang.bind(this, this._onLoadError));
+
+        this.widget.connect('destroy', Lang.bind(this,
+            function() {
+                this._bookmarkPage.disconnect(bookmarkPageId);
+                this._zoomIn.disconnect(zoomInId);
+                this._zoomOut.disconnect(zoomOutId);
+                findPrev.disconnect(findPrevId);
+                findNext.disconnect(findNextId);
+                this._copy.disconnect(copyId);
+                rotLeft.disconnect(rotLeftId);
+                rotRight.disconnect(rotRightId);
+                this._places.disconnect(placesId);
+                Application.application.disconnect(presentCurrentId);
+                Application.application.disconnect(nightModeId);
+            }));
     },
 
     _onLoadStarted: function() {
         this._bookmarkPage.enabled = false;
-        this._showPlaces.enabled = false;
+        this._places.enabled = false;
         this._copy.enabled = false;
     },
 
@@ -542,9 +560,20 @@ const PreviewView = new Lang.Class({
 
             let hasMultiplePages = (this._model.document.get_n_pages() > 1);
             this._bookmarkPage.enabled = hasMultiplePages && this._bookmarks;
-            this._showPlaces.enabled = hasMultiplePages;
+            this._places.enabled = hasMultiplePages;
 
             this._model.connect('page-changed', Lang.bind(this, this._onPageChanged));
+
+            this._updateNightMode();
+
+            this.widget.set_visible_child_full('view', Gtk.StackTransitionType.NONE);
+        }
+    },
+
+    _updateNightMode: function() {
+        if (this._model) {
+            let nightMode = Application.settings.get_boolean('night-mode');
+            this._model.set_inverted_colors(nightMode);
         }
     },
 
